This is data either extracted or included (with permission) to assist with illustrating and replicating the functionality of the package. Specifically, this data is used to illustrate conventions regarding a multiple probe design and how that may be constructed in this package.
Gilroyetal2015A data frame with 40 rows and 6 variables:
Participant name
Session number
Condition name
Responding rates
Phase number
Offset for phase line