Learn R Programming

fxl (version 1.7.3)

print.fxl: print.fxl

Description

Override the final call to print the fxl object. catches the obj and prints out layers in the sequence laid out by the user

Usage

# S3 method for fxl
print(x, ...)

Value

no return, executed for side effects

Arguments

x

fxl object

...

inherits from generic

Author

Shawn Gilroy <sgilroy1@lsu.edu>