Learn R Programming

fxl (version 1.7.3)

scr_anno_arrows: scr_anno_arrows

Description

Add a layer with arrows to direct attention on the plot

Usage

scr_anno_arrows(
  core_frame,
  arrows = NULL,
  facet = NULL,
  color = "black",
  length = 0.25,
  angle = 30,
  code = 2,
  lwd = 1,
  lty = 1
)

Value

a layer to the core plotting object

Arguments

core_frame

fxl class

arrows

list of keyed entries to be drawn on respective facets

facet

the facet which will be drawn upon

color

from base

length

from base

angle

from base

code

from base

lwd

from base

lty

from base

Author

Shawn Gilroy <sgilroy1@lsu.edu>

Details

Generally useful for avoiding a legend