Add a layer with arrows to direct attention on the plot
scr_anno_arrows(
core_frame,
arrows = NULL,
facet = NULL,
color = "black",
length = 0.25,
angle = 30,
code = 2,
lwd = 1,
lty = 1
)a layer to the core plotting object
fxl class
list of keyed entries to be drawn on respective facets
the facet which will be drawn upon
from base
from base
from base
from base
from base
from base
Shawn Gilroy <sgilroy1@lsu.edu>
Generally useful for avoiding a legend